django-campaign — django-campaign 0.3.0-pre documentation

### Navigation

- index
- next |
- django-campaign 0.3.0-pre documentation »

# django-campaign

Newsletter and campaign management for the Django webframework.

Django-campaign is an application for the Django webframework to make sending out newsletters to one or more groups of subscribers easy. If you need to send newsletters to thousands of subscribers it is easy to integrate django-campaign with django-mailer or some email sending providers through their APIs.

Some of the core features are:

- Multipart Emails made easy - just add a plain-text and a html-template.
- Full control over the Subscriber-Model and therefore the template context used to render the mails.
- Add context processors to add whatever you need to a mail template based on the recipient. This makes it easy to personalize messages.
- Allow viewing of the newsletters online and add a link to the web version to the outgoing emails.
- simple and optional subscribe/unsubscribe handling

## Contents

- Installation
- How to send Newsletters with django-campaign
- Available Settings
  - CAMPAIGN_BACKEND
  - CAMPAIGN_CONTEXT_PROCESSORS
  - CAMPAIGN_SUBSCRIBE_CALLBACK
  - CAMPAIGN_UNSUBSCRIBE_CALLBACK
- Backends
  - Writing your own Backend
  - Backend Methods
- Templates
  - E-Mail Templates
  - Other Templates
- Philisophy behind some of the concepts of django-campaign
  - Why is there no Subscriber-Model?

### Navigation

- index
- next |
- django-campaign 0.3.0-pre documentation »